@@ -10,12 +10,20 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.79'; # VERSION
+our $VERSION = '1.80'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-sub mvp_multivalue_args { qw( alien_build_command alien_install_command diag allow_dirty ) }
+sub mvp_multivalue_args { qw( 
+  alien_build_command
+  alien_install_command
+  alien_auto_include
+  alien_bin_requires
+  alien_helper
+  
+  diag
+  allow_dirty ) }
 
 sub configure
 {
@@ -64,28 +72,29 @@ sub configure
   );
 
   do { # installer stuff
-    my $installer = $self->payload->{installer} || 'MakeMaker';
+    my $installer = $self->payload->{installer};
     my %mb = map { $_ => $self->payload->{$_} } grep /^mb_/, keys %{ $self->payload };
     if(-e Path::Class::File->new('inc', 'My', 'ModuleBuild.pm'))
     {
-      $installer = 'ModuleBuild';
+      $installer ||= 'ModuleBuild';
       $mb{mb_class} = 'My::ModuleBuild'
         unless defined $mb{mb_class};
     }
-    if($installer eq 'Alien')
+    if(defined $installer && $installer eq 'Alien')
     {
       my %args = 
         map { $_ => $self->payload->{"alien_$_"} }
         map { s/^alien_//; $_ } 
         grep /^alien_/, keys %{ $self->payload };
-      $self->add_plugins([ Alien => \%args ]);
+      $self->add_plugins([ Alien => { %args, %mb } ]);
     }
-    elsif($installer eq 'ModuleBuild')
+    elsif(defined $installer && $installer eq 'ModuleBuild')
     {
       $self->add_plugins([ ModuleBuild => \%mb ]);
     }
     else
     {
+      $installer ||= 'MakeMaker';
       $self->add_plugins($installer);
     }
   };
@@ -242,7 +251,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.79
+version 1.80
 
 =head1 SYNOPSIS
 
